@@ -10,7 +10,7 @@ use Mojo::Util qw(humanize_bytes);
 
 use constant MACOS => $^O eq 'darwin';
 
-our $VERSION = '1.14';
+our $VERSION = '1.15';
 
 sub register {
   my ($self, $app, $config) = @_;
@@ -109,9 +109,10 @@ sub _dashboard {
 }
 
 sub _read_write {
-  my ($record, $id) = @_;
+  my ($all, $id) = @_;
   return unless my $stream = Mojo::IOLoop->stream($id);
-  @{$record}{qw(bytes_read bytes_written)} = ($stream->bytes_read, $stream->bytes_written);
+  @{$all->{workers}{$$}{connections}{$id}}{qw(bytes_read bytes_written)}
+    = ($stream->bytes_read, $stream->bytes_written);
 }
 
 sub _request {
@@ -133,7 +134,7 @@ sub _request {
       query      => $url->query->to_string,
       started    => time
     };
-    _read_write($_->{workers}{$$}{connections}{$id}, $id);
+    _read_write($_, $id);
     $_->{workers}{$$}{connections}{$id}{client} = $tx->remote_address;
   });
 
@@ -151,8 +152,7 @@ sub _request {
         elsif ($code > 199) { $_->{stats}{success}++ }
         elsif ($code)       { $_->{stats}{info}++ }
 
-        $worker->{connections}{$id}{request}{finished} = time;
-        $worker->{connections}{$id}{request}{status}   = $code;
+        @{$worker->{connections}{$id}{request}}{qw(finished status)} = (time, $code);
         $worker->{connections}{$id}{processed}++;
         $worker->{processed}++;
         $_->{processed}++;
@@ -164,14 +164,13 @@ sub _request {
 sub _rendered {
   my ($self, $c) = @_;
 
-  my $id   = $c->tx->connection;
-  my $map  = $self->{map};
-  my $conn = $map->writer->fetch->{workers}{$$}{connections}{$id};
-  return unless $conn && (my $req = $conn->{request});
-  $req->{time} = time - $req->{started};
-  @{$req}{qw(client status worker)} = ($conn->{client}, $c->res->code, $$);
+  my $id = $c->tx->connection;
+  $self->{map}->writer->change(sub {
+    return unless my $conn = $_->{workers}{$$}{connections}{$id};
+    return unless my $req  = $conn->{request};
+    $req->{time} = time - $req->{started};
+    @{$req}{qw(client status worker)} = ($conn->{client}, $c->res->code, $$);
 
-  $map->writer->change(sub {
     my $slowest = $_->{slowest};
     @$slowest = sort { $b->{time} <=> $a->{time} } @$slowest, $req;
     my %seen;
@@ -189,9 +188,7 @@ sub _resources {
     # macOS actually returns bytes instead of kilobytes
     $_->{workers}{$$}{maxrss} = $_->{workers}{$$}{maxrss} * 1000 unless MACOS;
 
-    for my $id (keys %{$_->{workers}{$$}{connections}}) {
-      _read_write($_->{workers}{$$}{connections}{$id}, $id);
-    }
+    for my $id (keys %{$_->{workers}{$$}{connections}}) { _read_write($_, $id) }
   });
 }
 
@@ -212,7 +209,9 @@ sub _slowest {
 
 sub _start {
   my ($self, $server, $app) = @_;
-  return unless $server->isa('Mojo::Server::Daemon');
+
+  return $app->log->warn('Server not suported by Mojolicious::Plugin::Status')
+    unless $server->isa('Mojo::Server::Daemon');
 
   # Register started workers
   Mojo::IOLoop->next_tick(sub {
@@ -235,9 +234,7 @@ sub _start {
   Mojo::IOLoop->recurring(5 => sub { $self->_resources });
 }
 
-sub _stats {
-  return {started => time, info => 0, success => 0, redirect => 0, client_error => 0, server_error => 0};
-}
+sub _stats { {started => time, info => 0, success => 0, redirect => 0, client_error => 0, server_error => 0} }
 
 sub _stream {
   my ($self, $id) = @_;
